@@ -3,12 +3,12 @@ package WordList::PersonName::Bible::EN;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-01'; # DATE
 our $DIST = 'WordList-PersonName-Bible-EN'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words",1998,"num_words_contains_nonword_chars",59,"shortest_word_len",2,"num_words_contains_whitespace",3,"longest_word_len",23,"avg_word_len",6.47347347347347,"num_words_contains_unicode",0); # STATS
+our %STATS = ("num_words_contain_unicode",0,"num_words_contains_nonword_chars",59,"num_words_contain_whitespace",3,"avg_word_len",6.47347347347347,"num_words_contains_unicode",0,"num_words_contain_nonword_chars",59,"num_words",1998,"num_words_contains_whitespace",3,"longest_word_len",23,"shortest_word_len",2); # STATS
 
 1;
 # ABSTRACT: All men mentioned in the bible
@@ -23,7 +23,7 @@ WordList::PersonName::Bible::EN - All men mentioned in the bible
 
 =head1 VERSION
 
-This document describes version 0.001 of WordList::PersonName::Bible::EN (from Perl distribution WordList-PersonName-Bible-EN), released on 2020-05-01.
+This document describes version 0.002 of WordList::PersonName::Bible::EN (from Perl distribution WordList-PersonName-Bible-EN), released on 2020-05-01.
 
 =head1 SYNOPSIS
 
@@ -52,6 +52,9 @@ This document describes version 0.001 of WordList::PersonName::Bible::EN (from P
  | avg_word_len                     | 6.47347347347347 |
  | longest_word_len                 | 23               |
  | num_words                        | 1998             |
+ | num_words_contain_nonword_chars  | 59               |
+ | num_words_contain_unicode        | 0                |
+ | num_words_contain_whitespace     | 3                |
  | num_words_contains_nonword_chars | 59               |
  | num_words_contains_unicode       | 0                |
  | num_words_contains_whitespace    | 3                |
